Lua_FightBossHurtPanel = class("Lua_FightBossHurtPanel", Lua_DisplayObject);
function Lua_FightBossHurtPanel:ctor(p)
    self:superCall("ctor", p, "FightBossHurtPanel_skin");
end

function Lua_FightBossHurtPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.wait_time = 0;
    self.aniWait = 0.2;

    self.curHurt = 0;
    self.totalHurt = 0;
    self.maxHurt = 1;
    self.maxValue = 1;
    self.showTarget = 1;
    self.showValue = 0;
    self.secondTarget = 0;
    self.addValue = 0;
    self.addValueStep = 1;
    self.speedRate = 1
    
    self.hurtBar:createSecondBar("chaos_forest_altas", "ui_hdsl_progress_003_f");
    self.hurtBar.typeValue = 3;
    self.hurtBar.fillMethodValue = 0;
    self.hurtBar.fillOrigin = 0;
    self.hurtBar:setSecondMaxValue(self.maxValue);
    self.hurtBar:setSecondValue(self.showValue);
    self.hurtBar:setMaxValue(self.maxValue);
    self.hurtBar:setValue(self.showValue);

    self:addLuaEvent("FIGHT_BOSSHURT_UPDATE", self, self.onHurtUpdate);
end

function Lua_FightBossHurtPanel:dispose()
    self:endTimer();
    self:superCall("dispose");
end

function Lua_FightBossHurtPanel:setData(templateId, stageId, speedRate)
    if templateId == Lua_FightDefine.TEMPLATE_ID_CHAOSFOREST then
        local config = DataCenter.chaosForestUtil:getLevelConfig(stageId);
        self:setStageConfig(config);
    end
    self.speedRate = speedRate
end

function Lua_FightBossHurtPanel:setSpeedRate(value)
    self.speedRate = value;
end

function Lua_FightBossHurtPanel:setStageConfig(config)
    if config == nil then
        return;
    end

    self.nameText.text = config.name;
    local monsterConfig = Lua_MonsterPlayerConfigData.getConfigData(config.monster_id);
    local monsterId = monsterConfig.fighter_list[1][1][1];
    monsterConfig = Lua_MonsterConfigData.getMonsterConfig(monsterId);
    self.icon:setAltas(monsterConfig.avatar_atlas_1, monsterConfig.avatar_sprite_1)
end

function Lua_FightBossHurtPanel:setHurtValue(value)
    self.curHurt = value;
    self.totalHurt = value;

    local index, curValue, prevValue, isFinally = DataCenter.chaosForestUtil:getMaxHurt(self.totalHurt);
    self.maxHurt = curValue;
    self.maxValue = curValue - prevValue;
    self.showValue = self.totalHurt - prevValue;
    self.isFinally = isFinally;

    self.stepText.text = LanUtil.formateStr(10043, tostring(index));
    self.hurtBar:setSecondMaxValue(self.maxValue);
    self.hurtBar:setSecondValue(self.showValue);
    self.hurtBar:setMaxValue(self.maxValue);
    self.hurtBar:setValue(self.showValue);
    if isFinally then
        self.hurtBar:setText(LanUtil.formateStr(10044, tostring(self.maxHurt), tostring(self.maxHurt)));
    else
        self.hurtBar:setText(LanUtil.formateStr(10044, tostring(self.totalHurt), tostring(self.maxHurt)));
    end
end

function Lua_FightBossHurtPanel:onHurtUpdate(value)
    self.totalHurt = self.totalHurt + value;

    if self.addValue == nil or self.addValue <= 0 then
        self.addValue = 0;
    end
    self.addValue = self.addValue + value;
    self.addValueStep = self.addValue / 1;

    if (self.maxValue - self.showValue) <= self.addValue then
        self.secondTarget = self.maxValue;
    else
        self.secondTarget = self.secondTarget + value;
    end

    self.wait_time = self.aniWait;
    self.startTime = getTime();
    self:startTimer();
end

function Lua_FightBossHurtPanel:startTimer()
    if self.bTimer ~= true then
        self.bTimer = true;
        self:addTimer("Lua_FightBossHurtPanel", 0.01, self, self.onTimer, nil, -1);
    end
end

function Lua_FightBossHurtPanel:endTimer()
    if self.bTimer == true then
        self.bTimer = false;
        self:removeTimer(self, self.onTimer);
    end
end

function Lua_FightBossHurtPanel:onTimer()
    local dt;
    if self.wait_time > 0 then
        self.hurtBar:setSecondMaxValue(self.maxValue);
        self.hurtBar:setSecondValue(self.secondTarget);

        dt = getTime() - self.startTime;
        self.wait_time = self.wait_time - dt;
        if self.wait_time <= 0 then
            self.wait_time = 0;
        end
        self.startTime = getTime();
    else
        if self.addValue <= 0 then
            self:endTimer();
            return;
        end

        local t = getTime();
        dt = (t - self.startTime) *  self.speedRate;
        self.startTime = t;

        local num = self.addValueStep * dt;
        self.addValue = self.addValue - num;
        if self.addValue <= 0 then
            num = num + self.addValue;
        end
        self.showValue = self.showValue + num;

        if self.showValue >= self.maxValue then
            self.showValue = self.showValue - self.maxValue;
            
            local index, curValue, prevValue, isFinally = DataCenter.chaosForestUtil:getMaxHurt(self.totalHurt);
            self.stepText.text = LanUtil.formateStr(10043, tostring(index));
            self.maxHurt = curValue;
            self.maxValue = curValue - prevValue;
            self.isFinally = isFinally;

            self.secondTarget = 0;
            self.hurtBar:setSecondValue(self.secondTarget);
            if self.addValue > self.maxValue then
                self.secondTarget = self.maxValue;
            else
                self.secondTarget = self.addValue;
            end
            self.wait_time = self.aniWait;
            self.startTime = getTime();
        end

        if self.isFinally and self.curHurt > self.maxHurt then
            self:showMaxHurt();
        else
            self.hurtBar:setMaxValue(self.maxValue);
            self.hurtBar:setPercent(self.showValue / self.maxValue);
        end

        self.curHurt = self.curHurt + num;
        if self.curHurt > self.totalHurt then
            self.curHurt = self.totalHurt;
        end

        self.hurtBar:setText(LanUtil.formateStr(10044, tostring(getPreciseDecimal(self.curHurt, 0)), tostring(self.maxHurt)));
    end
end

function Lua_FightBossHurtPanel:showMaxHurt()
    self.hurtBar:setSecondMaxValue(1);
    self.hurtBar:setSecondValue(1);
    self.hurtBar:setMaxValue(1);
    self.hurtBar:setValue(1);
    self.hurtBar:setText(LanUtil.formateStr(10044, tostring(self.maxHurt), tostring(self.maxHurt)));
end