-- 组队
Lua_FightTeamUpPanel = class("Lua_FightTeamUpPanel", Lua_DisplayObject);
function Lua_FightTeamUpPanel:ctor(p)
	self:superCall("ctor", p, "FightTeamUpPanel_skin");
end

function Lua_FightTeamUpPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.showState = true;

	self.showContainer = Lua_WindowUtil.createContaner(self.content, Vector3.zero);
	self.showContainer:SetActive(self.showState);

	self.infoBg:setParent(self.showContainer);

	self.leftItem = Lua_FightTeamItem.new(self.showContainer);
	self.leftItem:setLocation(-258, -80, 0);

	self.rightItem = Lua_FightTeamItem.new(self.showContainer);
	self.rightItem:setLocation(-258, -178, 0);

	self.openBtn:addClickFuntion(self, self.onOpenClick);
end

function Lua_FightTeamUpPanel:dispose()
	Lua_CommonUtil.removeTimer(self, self.onAutoHide)
	if self.leftItem ~= nil then
		self.leftItem:dispose();
		self.leftItem = nil;
	end
	if self.rightItem ~= nil then
		self.rightItem:dispose();
		self.rightItem = nil;
	end
	self:superCall("dispose");
end

function Lua_FightTeamUpPanel:setData(recordId, teamId)
	self.teamId = teamId;
	if self.recordId ~= recordId then
		self:updateData(recordId);
	end
	self.recordId = recordId;
end

function Lua_FightTeamUpPanel:updateData(recordId)
	local recordVo = DataCenter.fightData:getRecordVoById(recordId);
	self.showIcon:setEnable(recordVo == nil or recordVo.ownType == -1);
	
	local arr = DataCenter.fightData:getTeamArrById(self.teamId);
	if arr == nil then
		return;
	end

	local index = 0;
	for i = 1, arr:getSize() do
		if arr[i] ~= recordId then
			index = index + 1;
			if index == 1 then
				self.leftItem:setData(arr[i]);
			elseif index == 2 then
				self.rightItem:setData(arr[i]);
			end
		end
	end
end

function Lua_FightTeamUpPanel:setShowHide(value)
	self.showState = value;
	self:updateShowHide();
end

function Lua_FightTeamUpPanel:setAutoHide(value)
	value = value or 0
	Lua_CommonUtil.delayCall(value, self, self.onAutoHide)
end

function Lua_FightTeamUpPanel:onAutoHide()
	self:setShowHide(false)
end

function Lua_FightTeamUpPanel:onOpenClick()
	self.showState = not self.showState;
	self:updateShowHide();
end

function Lua_FightTeamUpPanel:updateShowHide()
	if self.showState then
		self.openBtn:setAltas("fight_atlas_1", "xui_xhd_button_004_n")
	else
		self.openBtn:setAltas("fight_atlas_1", "xui_xhd_button_003_n")
	end
	self.showContainer:SetActive(self.showState)
end

function Lua_FightTeamUpPanel:updateHp()
	self.leftItem:updateHp();
	self.rightItem:updateHp();
end










Lua_FightTeamItem = class("Lua_FightTeamItem", Lua_DisplayObject);
function Lua_FightTeamItem:ctor(p)
	self:superCall("ctor", p, "FightTeamItem_skin");
end

function Lua_FightTeamItem:buildShowItem()
	self:superCall("buildShowItem");

	self.attackerAvatar = Lua_AvatarItem.new(self.content);
	self.attackerAvatar:setRoleAvatar(0);
	self.attackerAvatar:setRoleFrame(0);
	self.attackerAvatar:setScale(0.55, 0.55, 0.55);

	self.bossAvatar = Lua_AvatarItem.new(self.content);
	self.bossAvatar:setRoleAvatar(0);
	self.bossAvatar:setRoleFrame(0);
	self.bossAvatar:setSiblingIndex(3);
	self.bossAvatar:setLocation(154, 1, 0);
	self.bossAvatar:setScale(0.55, 0.55, 0.55);

	self.bg.clickScale = false;
	self.bg:addClickFuntion(self, self.onClick);
end

function Lua_FightTeamItem:setData(recordId)
	if self.recordId == recordId then
		return;
	end
	self.recordId = recordId;

	self.recordVo = DataCenter.fightData:getRecordVoById(recordId);
	if self.recordVo == nil then
		return;
	end

	local attacker = self.recordVo.attacker;
	self.attackerAvatar:setRoleDressUp(attacker.dress_info);
	self.attackerAvatar:setRoleName(attacker.name);

	local arr = self.recordVo:getFighterArr(Lua_FightDefine.FIGHT_DEFENDER, 2);
	if arr ~= nil and arr:getSize() > 0 then
		local boosId = self.recordVo:getFighterInfo(arr[1]);
		local config = Lua_MonsterConfigData.getMonsterConfig(boosId);
		if config ~= nil and config.heroVo ~= nil then
			self.bossAvatar:setAvatar(config.heroVo.avatar_atlas_1, config.heroVo.avatar_sprite_1, 0.9);
		end
		self.campIcon:setAltas("common_altas_2", "xui_common_attribute_"..config.heroVo.campType);
	end
	
	self:updateHp();
end

function Lua_FightTeamItem:updateHp()
	if self.recordVo == nil then
		return;
	end

	local maxHp = self.recordVo.attackerMaxHp;
	local hp = self.recordVo.attackerHp;
	maxHp = maxHp == nil and 1 or maxHp;
	hp = hp == nil and 1 or hp;
	self.attackerBar:setMaxValue(maxHp);
	self.attackerBar:setValue(hp);

	maxHp = self.recordVo.defenderMaxHp;
	hp = self.recordVo.defenderHp;
	maxHp = maxHp == nil and 1 or maxHp;
	hp = hp == nil and 1 or hp;
	self.bossBar:setMaxValue(maxHp);
	self.bossBar:setValue(hp);
end

function Lua_FightTeamItem:onClick(go)
	local player = DataCenter.fightData:getFightPlayerById(self.recordId);
	if player == nil or player.isPlayEnd == true then
		OperateAlert.showLangValue(420091);
		return;
	end
	DataCenter.fightData:showFightToStageByRid(self.recordId);
end

function Lua_FightTeamItem:dispose()
	if self.attackerAvatar ~= nil then
		self.attackerAvatar:dispose();
		self.attackerAvatar = nil;
	end
	if self.bossAvatar ~= nil then
		self.bossAvatar:dispose();
		self.bossAvatar = nil;
	end
	self.recordVo = nil;
	self:superCall("dispose");
end