checkRequire("Lua_FightResultBaseWindow");
checkRequire("Lua_PeakDuelFightUpgradeItem");
Lua_PeakDuelFightWinWindow = class("Lua_PeakDuelFightWinWindow", Lua_FightResultBaseWindow);
function Lua_PeakDuelFightWinWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_PeakDuelFightWinWindow";
	self.skinName = "PeakDuelResultWindow_skin";
	self.winBgPath = "/images/fight/xui_zd_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/effects/uiEffects/ui_zdjs_sl_01", Lua_LoadFileType.UNITY3D);
	self.openSound = "fight_win_01";
	
	self.bIsWin = true;
	self.bIsShowCountTime = true;
	self.bIsShowHurtBtn = true;
end

function Lua_PeakDuelFightWinWindow:buildShowItem()
	self:superCall("buildShowItem");

	if Lua_WindowUtil.isWindowShowing("Lua_PeakDuelWindow") == false then
		self.btnSure:setLocation(-180, 277.5, 0);
		self.btnReturn:setEnable(true);
		self.btnReturn:setLocation(180, 277.5, 0);
	else
		self.btnSure:setLocation(0, 277.5, 0);
		self.btnReturn:setEnable(false);
	end

	self.btnSure:addClickFuntion(self, self.onBtnSureClick);
	self.btnReturn:addClickFuntion(self, self.onBtnReturnClick);
end

function Lua_PeakDuelFightWinWindow:dispose()
	TweenUtil.getInstance():stop(self.segment_icon_old.mainContent);
	TweenUtil.getInstance():stop(self.segment_icon.mainContent);
	if self.upgradeArr ~= nil then
		self.upgradeArr:dispose();
		self.upgradeArr:clear();
		self.upgradeArr = nil;
	end
	self:clearRewardList();
	self:superCall("dispose");
end

function Lua_PeakDuelFightWinWindow:showWin(param)
	self:superCall("showWin", param);

	local configData = DataCenter.peakDuelUtil:getSegmentInfoByid(param.segment_lvl);
	if configData == nil then
		return;
	end

	self.segment_icon:setAltas("peak_duel_altas", configData.icon_path);
	
	if param.is_upgrade == 1 and param.segment_lvl ~= param.old_segment_lvl then -- 段位发生变化
		self.segment_icon:setLocation(150, 50, 0);
		self.segment_arrow:setEnable(true);

		local configData2 = DataCenter.peakDuelUtil:getSegmentInfoByid(param.old_segment_lvl);
		self.segment_icon_old:setAltas("peak_duel_altas", configData2.icon_path);
		self.segment_icon_old:setEnable(true);
		self.segment_icon_old:setLocation(0, 50, 0);
		TweenUtil.getInstance():addTweenTargetPos(self.segment_icon_old.mainContent, 0.5, 0, -150, 50, 0, self, self.onTweenCompleted)
	else
		self.segment_icon:setLocation(0, 50, 0);
		self.segment_arrow:setEnable(false);
		self.segment_icon_old:setEnable(false);
	end

	if param.is_upgrade == 1 then
		self.upResultDic = {}; -- key:升段赛的第几场 value:战斗结果 1胜利 0失败
		if param.upgrade_result ~= nil then
			local obj;
			for i = 1, #param.upgrade_result do
				obj = param.upgrade_result[i];
				self.upResultDic[obj.key] = obj.value;
			end
		end

		self:showUpgrade(configData.upgrade_segment_cond[1]);
	else
		if self.expBar == nil then
			self.expBar = UICreate.createProgressBar(self.content, "common_altas_1", "ui_common_progress_001_b", "common_altas_1", "ui_common_progress_001_f", 0, 0, 124, 10);
			self.expBar:createSecondBar("common_altas_1", "ui_common_progress_002_f");
		end
		self.expBar:setSecondMaxValue(configData.segment_lvl_cond);
		self.expBar:setSecondValue(param.segment_lvl_exp);

		self.expBar:setMaxValue(configData.segment_lvl_cond);
		self.expBar:setValue(param.cache_exp);
	end

	self.exp.text = LanUtil.formateStr("段位经验：{1}", param.segment_lvl_exp);
	self.score.text = LanUtil.formateStr("精英积分：{1}", param.score);

	if param.exp_change == 0 then
		self.exp_arrow:setEnable(false);
		self.exp_change.text = "不变";
	else
		self.exp_arrow:setEnable(true);
		if param.exp_change > 0 then
			self.exp_arrow:setAltas("common_altas_3", "ui_djc_label_06");
		else
			self.exp_arrow:setAltas("common_altas_3", "ui_djc_label_05");
		end
		self.exp_change.text = Mathf.Abs(param.exp_change);
	end

	if param.score_change == 0 then
		self.score_arrow:setEnable(false);
		self.score_change.text = "不变";
	else
		self.score_arrow:setEnable(true);
		if param.score_change > 0 then
			self.score_arrow:setAltas("common_altas_3", "ui_djc_label_06");
		else
			self.score_arrow:setAltas("common_altas_3", "ui_djc_label_05");
		end
		self.score_change.text = Mathf.Abs(param.score_change);
	end

	self:updateRewards(param.item_list);
end

function Lua_PeakDuelFightWinWindow:onTweenCompleted()
	TweenUtil.getInstance():addTweenTargetAlpha(self.segment_icon.mainContent, 0.5, 0, -1, true);
end

function Lua_PeakDuelFightWinWindow:showUpgrade(num)
	if self.upgradeArr == nil then
		self.upgradeArr = Array();
	end

	local len = num - self.upgradeArr:getSize();
	while (len > 0) do
		item = Lua_PeakDuelFightUpgradeItem.new(self.content);
		self.upgradeArr:add(item);
		len = len - 1;
	end

	while (len < 0) do
		item = self.upgradeArr:remove(1);
		item:dispose();
		len = len + 1;
	end

	len = self.upgradeArr:getSize();
	local space = 50;
	local w;
	local posX;
	for i = 1, len do
		item = self.upgradeArr[i];
		item:setData(self.upResultDic[i]);

		w = -(space * len) / 2 + space / 2;
		posX = ((i - 1) % len) * space + w;
		item:setLocation(posX, -60, 0);
	end
end

function Lua_PeakDuelFightWinWindow:updateRewards(itemList)
	if itemList == nil or #itemList <= 0 then
		self:clearRewardList();
		return;
	end

	local tab = DataCenter.packData:getRewardDic(itemList);
	local arr = DataCenter.packData:getRewardList(tab);
	if self.rewardList == nil then
		local len = arr:getSize();
		if len > 4 then
			self.rewardList = Lua_DragList.new(self.content, 540, 232.5, Lua_AxisDefine.Vertical);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 135, 112, 4);
		else
			self.rewardList = Lua_DragList.new(self.content, len * 135, 155, Lua_AxisDefine.Horizontal);
			self.rewardList:setListCell(Lua_FightResultRewardItem, 135, 112, 1);
		end
		self.rewardList:setCellSpacing(0, 40);
		self.rewardList:setLocation(0, -195, 0);
	end
	self.rewardList:setArrayData(arr);
	self.rewardList.canDrag = not self.rewardList.isTheEnd;
end

function Lua_PeakDuelFightWinWindow:clearRewardList()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
end

function Lua_PeakDuelFightWinWindow:onBtnSureClick(go)
	self:hide();
end

function Lua_PeakDuelFightWinWindow:onBtnReturnClick(go)
	DataCenter.funcPathUtil:gotoFunction(1025, true)
end